summaryrefslogtreecommitdiffstats
path: root/knotes/knote.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'knotes/knote.cpp')
-rw-r--r--knotes/knote.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/knotes/knote.cpp b/knotes/knote.cpp
index b68a342f..a90d891b 100644
--- a/knotes/knote.cpp
+++ b/knotes/knote.cpp
@@ -219,7 +219,7 @@ KNote::KNote( TQDomDocument buildDoc, Journal *j, TQWidget *parent, const char *
// no config file yet? -> use the default display config if available
// we want to write to configFile, so use "false"
- bool newNote = !KIO::NetAccess::exists( KURL::fromPathOrURL( configFile ), false, 0 );
+ bool newNote = !TDEIO::NetAccess::exists( KURL::fromPathOrURL( configFile ), false, 0 );
m_config = new KNoteConfig( KSharedConfig::openConfig( configFile, false, false ) );
m_config->readConfig();
@@ -227,7 +227,7 @@ KNote::KNote( TQDomDocument buildDoc, Journal *j, TQWidget *parent, const char *
if ( newNote )
{
// until tdelibs provides copying of KConfigSkeletons (KDE 3.4)
KNotesGlobalConfig *globalConfig = KNotesGlobalConfig::self();
m_config->setBgColor( globalConfig->bgColor() );
m_config->setFgColor( globalConfig->fgColor() );
@@ -324,7 +324,7 @@ KNote::KNote( TQDomDocument buildDoc, Journal *j, TQWidget *parent, const char *
m_fold->setMask( TQRegion( m_fold->pixmap()->createHeuristicMask() ) );
// if this is a new note put on current desktop - we can't use defaults
// in KConfig XT since only _changes_ will be stored in the config file
int desktop = m_config->desktop();
if ( desktop < 0 && desktop != NETWinInfo::OnAllDesktops )
desktop = KWin::currentDesktop();
@@ -410,7 +410,7 @@ void KNote::slotKill( bool force )
TQString configFile = TDEGlobal::dirs()->saveLocation( "appdata", "notes/" );
configFile += m_journal->uid();
- if ( !KIO::NetAccess::del( KURL::fromPathOrURL( configFile ), this ) )
+ if ( !TDEIO::NetAccess::del( KURL::fromPathOrURL( configFile ), this ) )
kdError(5500) << "Can't remove the note config: " << configFile << endl;
emit sigKillNote( m_journal );
@@ -654,15 +654,15 @@ void KNote::sync( const TQString& app )
hash.update( m_editor->text().utf8() );
hash.hexDigest( result );
- // hacky... not possible with KConfig XT
- KConfig *config = m_config->config();
+ // hacky... not possible with TDEConfig XT
+ TDEConfig *config = m_config->config();
config->setGroup( "Synchronisation" );
config->writeEntry( app, result.data() );
}
bool KNote::isNew( const TQString& app ) const
{
- KConfig *config = m_config->config();
+ TDEConfig *config = m_config->config();
config->setGroup( "Synchronisation" );
TQString hash = config->readEntry( app );
return hash.isEmpty();
@@ -679,7 +679,7 @@ bool KNote::isModified( const TQString& app ) const
hash.update( m_editor->text().utf8() );
hash.hexDigest();
- KConfig *config = m_config->config();
+ TDEConfig *config = m_config->config();
config->setGroup( "Synchronisation" );
TQString orig = config->readEntry( app );
@@ -227,7 +227,7 @@ KNote::KNote( TQDomDocument buildDoc, Journal *j, TQWidget *parent, const char *
if ( newNote )
{
- // until tdelibs provides copying of KConfigSkeletons (KDE 3.4)
+ // until tdelibs provides copying of TDEConfigSkeletons (KDE 3.4)
KNotesGlobalConfig *globalConfig = KNotesGlobalConfig::self();
m_config->setBgColor( globalConfig->bgColor() );
@@ -324,7 +324,7 @@ KNote::KNote( TQDomDocument buildDoc, Journal *j, TQWidget *parent, const char *
m_fold->setMask( TQRegion( m_fold->pixmap()->createHeuristicMask() ) );
// if this is a new note put on current desktop - we can't use defaults
- // in KConfig XT since only _changes_ will be stored in the config file
+ // in TDEConfig XT since only _changes_ will be stored in the config file
int desktop = m_config->desktop();
if ( desktop < 0 && desktop != NETWinInfo::OnAllDesktops )